src.imagedata.formats package
=============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   src.imagedata.formats.dicomlib

Submodules
----------

src.imagedata.formats.abstractplugin module
-------------------------------------------

.. automodule:: src.imagedata.formats.abstractplugin
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.formats.dicomplugin module
----------------------------------------

.. automodule:: src.imagedata.formats.dicomplugin
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.formats.itkplugin module
--------------------------------------

.. automodule:: src.imagedata.formats.itkplugin
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.formats.matplugin module
--------------------------------------

.. automodule:: src.imagedata.formats.matplugin
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.formats.niftiplugin module
----------------------------------------

.. automodule:: src.imagedata.formats.niftiplugin
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: src.imagedata.formats
   :members:
   :undoc-members:
   :show-inheritance:
